Module integral_types

Module integral_types 

Structs

Duration
Matches the integral ros1 duration type, with extensions for ease of use NOTE: Is not a message in and of itself use std_msgs/Duration for that
Time
Matches the integral ros1 type time, with extensions for ease of use NOTE: in ROS1 “Time” is not a message in and of itself and std_msgs/Time should be used. However, in ROS2 “Time” is a message and part of builtin_interfaces/Time.